@@ -1,3 +1,7 @@
+# Licensed to Elasticsearch B.V under one or more agreements.
+# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
+# See the LICENSE file in the project root for more information
+
 from .utils import NamespacedClient, query_params, _make_path
 
 
@@ -7,12 +11,12 @@ class CatClient(NamespacedClient):
         """
         Shows information about currently configured aliases to indices including
         filter and routing infos.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/cat-alias.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/cat-alias.html>`_
 
         :arg name: A comma-separated list of alias names to return
         :arg expand_wildcards: Whether to expand wildcard expression to
-            concrete indices that are open, closed or both.   Valid choices: open,
-            closed, hidden, none, all   Default: all
+            concrete indices that are open, closed or both.  Valid choices: open,
+            closed, hidden, none, all  Default: all
         :arg format: a short version of the Accept header, e.g. json,
             yaml
         :arg h: Comma-separated list of column names to display
@@ -32,11 +36,11 @@ class CatClient(NamespacedClient):
         """
         Provides a snapshot of how many shards are allocated to each data node and how
         much disk space they are using.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/cat-allocation.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/cat-allocation.html>`_
 
         :arg node_id: A comma-separated list of node IDs or names to
             limit the returned information
-        :arg bytes: The unit in which to display byte values   Valid
+        :arg bytes: The unit in which to display byte values  Valid
             choices: b, k, kb, m, mb, g, gb, t, tb, p, pb
         :arg format: a short version of the Accept header, e.g. json,
             yaml
@@ -62,7 +66,7 @@ class CatClient(NamespacedClient):
         """
         Provides quick access to the document count of the entire cluster, or
         individual indices.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/cat-count.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/cat-count.html>`_
 
         :arg index: A comma-separated list of index names to limit the
             returned information
@@ -82,7 +86,7 @@ class CatClient(NamespacedClient):
     def health(self, params=None, headers=None):
         """
         Returns a concise representation of the cluster health.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/cat-health.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/cat-health.html>`_
 
         :arg format: a short version of the Accept header, e.g. json,
             yaml
@@ -90,9 +94,9 @@ class CatClient(NamespacedClient):
         :arg help: Return help information
         :arg s: Comma-separated list of column names or column aliases
             to sort by
-        :arg time: The unit in which to display time values   Valid
+        :arg time: The unit in which to display time values  Valid
             choices: d, h, m, s, ms, micros, nanos
-        :arg ts: Set to false to disable timestamping    Default: True
+        :arg ts: Set to false to disable timestamping  Default: True
         :arg v: Verbose mode. Display column headers
         """
         return self.transport.perform_request(
@@ -103,7 +107,7 @@ class CatClient(NamespacedClient):
     def help(self, params=None, headers=None):
         """
         Returns help for the Cat APIs.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/cat.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/cat.html>`_
 
         :arg help: Return help information
         :arg s: Comma-separated list of column names or column aliases
@@ -132,21 +136,21 @@ class CatClient(NamespacedClient):
         """
         Returns information about indices: number of primaries and replicas, document
         counts, disk size, ...
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/cat-indices.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/cat-indices.html>`_
 
         :arg index: A comma-separated list of index names to limit the
             returned information
-        :arg bytes: The unit in which to display byte values   Valid
+        :arg bytes: The unit in which to display byte values  Valid
             choices: b, k, kb, m, mb, g, gb, t, tb, p, pb
         :arg expand_wildcards: Whether to expand wildcard expression to
-            concrete indices that are open, closed or both.   Valid choices: open,
-            closed, hidden, none, all   Default: all
+            concrete indices that are open, closed or both.  Valid choices: open,
+            closed, hidden, none, all  Default: all
         :arg format: a short version of the Accept header, e.g. json,
             yaml
         :arg h: Comma-separated list of column names to display
         :arg health: A health status ("green", "yellow", or "red" to
-            filter only indices matching the specified health status   Valid
-            choices: green, yellow, red
+            filter only indices matching the specified health status  Valid choices:
+            green, yellow, red
         :arg help: Return help information
         :arg include_unloaded_segments: If set to true segment stats
             will include stats for segments that are not currently loaded into
@@ -158,7 +162,7 @@ class CatClient(NamespacedClient):
         :arg pri: Set to true to return stats only for primary shards
         :arg s: Comma-separated list of column names or column aliases
             to sort by
-        :arg time: The unit in which to display time values   Valid
+        :arg time: The unit in which to display time values  Valid
             choices: d, h, m, s, ms, micros, nanos
         :arg v: Verbose mode. Display column headers
         """
@@ -170,7 +174,7 @@ class CatClient(NamespacedClient):
     def master(self, params=None, headers=None):
         """
         Returns information about the master node.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/cat-master.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/cat-master.html>`_
 
         :arg format: a short version of the Accept header, e.g. json,
             yaml
@@ -203,9 +207,9 @@ class CatClient(NamespacedClient):
     def nodes(self, params=None, headers=None):
         """
         Returns basic statistics about performance of cluster nodes.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/cat-nodes.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/cat-nodes.html>`_
 
-        :arg bytes: The unit in which to display byte values   Valid
+        :arg bytes: The unit in which to display byte values  Valid
             choices: b, k, kb, m, mb, g, gb, t, tb, p, pb
         :arg format: a short version of the Accept header, e.g. json,
             yaml
@@ -219,7 +223,7 @@ class CatClient(NamespacedClient):
             to master node
         :arg s: Comma-separated list of column names or column aliases
             to sort by
-        :arg time: The unit in which to display time values   Valid
+        :arg time: The unit in which to display time values  Valid
             choices: d, h, m, s, ms, micros, nanos
         :arg v: Verbose mode. Display column headers
         """
@@ -233,13 +237,13 @@ class CatClient(NamespacedClient):
     def recovery(self, index=None, params=None, headers=None):
         """
         Returns information about index shard recoveries, both on-going completed.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/cat-recovery.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/cat-recovery.html>`_
 
         :arg index: Comma-separated list or wildcard expression of index
             names to limit the returned information
         :arg active_only: If `true`, the response only includes ongoing
             shard recoveries
-        :arg bytes: The unit in which to display byte values   Valid
+        :arg bytes: The unit in which to display byte values  Valid
             choices: b, k, kb, m, mb, g, gb, t, tb, p, pb
         :arg detailed: If `true`, the response includes detailed
             information about shard recoveries
@@ -249,7 +253,7 @@ class CatClient(NamespacedClient):
         :arg help: Return help information
         :arg s: Comma-separated list of column names or column aliases
             to sort by
-        :arg time: The unit in which to display time values   Valid
+        :arg time: The unit in which to display time values  Valid
             choices: d, h, m, s, ms, micros, nanos
         :arg v: Verbose mode. Display column headers
         """
@@ -263,11 +267,11 @@ class CatClient(NamespacedClient):
     def shards(self, index=None, params=None, headers=None):
         """
         Provides a detailed view of shard allocation on nodes.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/cat-shards.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/cat-shards.html>`_
 
         :arg index: A comma-separated list of index names to limit the
             returned information
-        :arg bytes: The unit in which to display byte values   Valid
+        :arg bytes: The unit in which to display byte values  Valid
             choices: b, k, kb, m, mb, g, gb, t, tb, p, pb
         :arg format: a short version of the Accept header, e.g. json,
             yaml
@@ -279,7 +283,7 @@ class CatClient(NamespacedClient):
             to master node
         :arg s: Comma-separated list of column names or column aliases
             to sort by
-        :arg time: The unit in which to display time values   Valid
+        :arg time: The unit in which to display time values  Valid
             choices: d, h, m, s, ms, micros, nanos
         :arg v: Verbose mode. Display column headers
         """
@@ -291,11 +295,11 @@ class CatClient(NamespacedClient):
     def segments(self, index=None, params=None, headers=None):
         """
         Provides low-level information about the segments in the shards of an index.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/cat-segments.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/cat-segments.html>`_
 
         :arg index: A comma-separated list of index names to limit the
             returned information
-        :arg bytes: The unit in which to display byte values   Valid
+        :arg bytes: The unit in which to display byte values  Valid
             choices: b, k, kb, m, mb, g, gb, t, tb, p, pb
         :arg format: a short version of the Accept header, e.g. json,
             yaml
@@ -313,7 +317,7 @@ class CatClient(NamespacedClient):
     def pending_tasks(self, params=None, headers=None):
         """
         Returns a concise representation of the cluster pending tasks.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/cat-pending-tasks.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/cat-pending-tasks.html>`_
 
         :arg format: a short version of the Accept header, e.g. json,
             yaml
@@ -325,7 +329,7 @@ class CatClient(NamespacedClient):
             to master node
         :arg s: Comma-separated list of column names or column aliases
             to sort by
-        :arg time: The unit in which to display time values   Valid
+        :arg time: The unit in which to display time values  Valid
             choices: d, h, m, s, ms, micros, nanos
         :arg v: Verbose mode. Display column headers
         """
@@ -338,7 +342,7 @@ class CatClient(NamespacedClient):
         """
         Returns cluster-wide thread pool statistics per node. By default the active,
         queue and rejected statistics are returned for all thread pools.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/cat-thread-pool.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/cat-thread-pool.html>`_
 
         :arg thread_pool_patterns: A comma-separated list of regular-
             expressions to filter the thread pools in the output
@@ -352,7 +356,7 @@ class CatClient(NamespacedClient):
             to master node
         :arg s: Comma-separated list of column names or column aliases
             to sort by
-        :arg size: The multiplier in which to display values   Valid
+        :arg size: The multiplier in which to display values  Valid
             choices: , k, m, g, t, p
         :arg v: Verbose mode. Display column headers
         """
@@ -368,11 +372,11 @@ class CatClient(NamespacedClient):
         """
         Shows how much heap memory is currently being used by fielddata on every data
         node in the cluster.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/cat-fielddata.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/cat-fielddata.html>`_
 
         :arg fields: A comma-separated list of fields to return in the
             output
-        :arg bytes: The unit in which to display byte values   Valid
+        :arg bytes: The unit in which to display byte values  Valid
             choices: b, k, kb, m, mb, g, gb, t, tb, p, pb
         :arg format: a short version of the Accept header, e.g. json,
             yaml
@@ -393,7 +397,7 @@ class CatClient(NamespacedClient):
     def plugins(self, params=None, headers=None):
         """
         Returns information about installed plugins across nodes node.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/cat-plugins.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/cat-plugins.html>`_
 
         :arg format: a short version of the Accept header, e.g. json,
             yaml
@@ -415,7 +419,7 @@ class CatClient(NamespacedClient):
     def nodeattrs(self, params=None, headers=None):
         """
         Returns information about custom node attributes.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/cat-nodeattrs.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/cat-nodeattrs.html>`_
 
         :arg format: a short version of the Accept header, e.g. json,
             yaml
@@ -437,7 +441,7 @@ class CatClient(NamespacedClient):
     def repositories(self, params=None, headers=None):
         """
         Returns information about snapshot repositories registered in the cluster.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/cat-repositories.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/cat-repositories.html>`_
 
         :arg format: a short version of the Accept header, e.g. json,
             yaml
@@ -461,7 +465,7 @@ class CatClient(NamespacedClient):
     def snapshots(self, repository=None, params=None, headers=None):
         """
         Returns all snapshots in a specific repository.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/cat-snapshots.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/cat-snapshots.html>`_
 
         :arg repository: Name of repository from which to fetch the
             snapshot information
@@ -475,7 +479,7 @@ class CatClient(NamespacedClient):
             to master node
         :arg s: Comma-separated list of column names or column aliases
             to sort by
-        :arg time: The unit in which to display time values   Valid
+        :arg time: The unit in which to display time values  Valid
             choices: d, h, m, s, ms, micros, nanos
         :arg v: Verbose mode. Display column headers
         """
@@ -502,7 +506,7 @@ class CatClient(NamespacedClient):
         """
         Returns information about the tasks currently executing on one or more nodes in
         the cluster.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/tasks.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/tasks.html>`_
 
         :arg actions: A comma-separated list of actions that should be
             returned. Leave empty to return all.
@@ -519,7 +523,7 @@ class CatClient(NamespacedClient):
             Set to -1 to return all.
         :arg s: Comma-separated list of column names or column aliases
             to sort by
-        :arg time: The unit in which to display time values   Valid
+        :arg time: The unit in which to display time values  Valid
             choices: d, h, m, s, ms, micros, nanos
         :arg v: Verbose mode. Display column headers
         """
@@ -531,7 +535,7 @@ class CatClient(NamespacedClient):
     def templates(self, name=None, params=None, headers=None):
         """
         Returns information about existing templates.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/cat-templates.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/cat-templates.html>`_
 
         :arg name: A pattern that returned template names must match
         :arg format: a short version of the Accept header, e.g. json,
@@ -554,13 +558,13 @@ class CatClient(NamespacedClient):
     def ml_data_frame_analytics(self, id=None, params=None, headers=None):
         """
         Gets configuration and usage information about data frame analytics jobs.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/cat-dfanalytics.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/cat-dfanalytics.html>`_
 
         :arg id: The ID of the data frame analytics to fetch
         :arg allow_no_match: Whether to ignore if a wildcard expression
             matches no configs. (This includes `_all` string or when no configs have
             been specified)
-        :arg bytes: The unit in which to display byte values   Valid
+        :arg bytes: The unit in which to display byte values  Valid
             choices: b, k, kb, m, mb, g, gb, t, tb, p, pb
         :arg format: a short version of the Accept header, e.g. json,
             yaml
@@ -568,7 +572,7 @@ class CatClient(NamespacedClient):
         :arg help: Return help information
         :arg s: Comma-separated list of column names or column aliases
             to sort by
-        :arg time: The unit in which to display time values   Valid
+        :arg time: The unit in which to display time values  Valid
             choices: d, h, m, s, ms, micros, nanos
         :arg v: Verbose mode. Display column headers
         """
@@ -583,7 +587,7 @@ class CatClient(NamespacedClient):
     def ml_datafeeds(self, datafeed_id=None, params=None, headers=None):
         """
         Gets configuration and usage information about datafeeds.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/cat-datafeeds.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/cat-datafeeds.html>`_
 
         :arg datafeed_id: The ID of the datafeeds stats to fetch
         :arg allow_no_datafeeds: Whether to ignore if a wildcard
@@ -595,7 +599,7 @@ class CatClient(NamespacedClient):
         :arg help: Return help information
         :arg s: Comma-separated list of column names or column aliases
             to sort by
-        :arg time: The unit in which to display time values   Valid
+        :arg time: The unit in which to display time values  Valid
             choices: d, h, m, s, ms, micros, nanos
         :arg v: Verbose mode. Display column headers
         """
@@ -610,13 +614,13 @@ class CatClient(NamespacedClient):
     def ml_jobs(self, job_id=None, params=None, headers=None):
         """
         Gets configuration and usage information about anomaly detection jobs.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/cat-anomaly-detectors.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/cat-anomaly-detectors.html>`_
 
         :arg job_id: The ID of the jobs stats to fetch
         :arg allow_no_jobs: Whether to ignore if a wildcard expression
             matches no jobs. (This includes `_all` string or when no jobs have been
             specified)
-        :arg bytes: The unit in which to display byte values   Valid
+        :arg bytes: The unit in which to display byte values  Valid
             choices: b, k, kb, m, mb, g, gb, t, tb, p, pb
         :arg format: a short version of the Accept header, e.g. json,
             yaml
@@ -624,7 +628,7 @@ class CatClient(NamespacedClient):
         :arg help: Return help information
         :arg s: Comma-separated list of column names or column aliases
             to sort by
-        :arg time: The unit in which to display time values   Valid
+        :arg time: The unit in which to display time values  Valid
             choices: d, h, m, s, ms, micros, nanos
         :arg v: Verbose mode. Display column headers
         """
@@ -650,13 +654,13 @@ class CatClient(NamespacedClient):
     def ml_trained_models(self, model_id=None, params=None, headers=None):
         """
         Gets configuration and usage information about inference trained models.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/cat-trained-model.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/cat-trained-model.html>`_
 
         :arg model_id: The ID of the trained models stats to fetch
         :arg allow_no_match: Whether to ignore if a wildcard expression
             matches no trained models. (This includes `_all` string or when no
-            trained models have been specified)    Default: True
-        :arg bytes: The unit in which to display byte values   Valid
+            trained models have been specified)  Default: True
+        :arg bytes: The unit in which to display byte values  Valid
             choices: b, k, kb, m, mb, g, gb, t, tb, p, pb
         :arg format: a short version of the Accept header, e.g. json,
             yaml
@@ -667,7 +671,7 @@ class CatClient(NamespacedClient):
             to sort by
         :arg size: specifies a max number of trained models to get
             Default: 100
-        :arg time: The unit in which to display time values   Valid
+        :arg time: The unit in which to display time values  Valid
             choices: d, h, m, s, ms, micros, nanos
         :arg v: Verbose mode. Display column headers
         """
@@ -688,7 +692,7 @@ class CatClient(NamespacedClient):
     def transforms(self, transform_id=None, params=None, headers=None):
         """
         Gets configuration and usage information about transforms.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/cat-transforms.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/cat-transforms.html>`_
 
         :arg transform_id: The id of the transform for which to get
             stats. '_all' or '*' implies all transforms
@@ -704,7 +708,7 @@ class CatClient(NamespacedClient):
             to sort by
         :arg size: specifies a max number of transforms to get, defaults
             to 100
-        :arg time: The unit in which to display time values   Valid
+        :arg time: The unit in which to display time values  Valid
             choices: d, h, m, s, ms, micros, nanos
         :arg v: Verbose mode. Display column headers
         """
