@@ -1,3 +1,7 @@
+# Licensed to Elasticsearch B.V under one or more agreements.
+# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
+# See the LICENSE file in the project root for more information
+
 from .utils import NamespacedClient, SKIP_IN_PATH, query_params, _make_path
 
 
@@ -6,7 +10,7 @@ class EqlClient(NamespacedClient):
     def search(self, index, body, params=None, headers=None):
         """
         Returns results matching a query expressed in Event Query Language (EQL)
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/eql.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/eql-search-api.html>`_
 
         :arg index: The name of the index to scope the operation
         :arg body: Eql request body. Use the `query` to limit the query
