@@ -1,3 +1,7 @@
+# Licensed to Elasticsearch B.V under one or more agreements.
+# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
+# See the LICENSE file in the project root for more information
+
 from .utils import NamespacedClient, query_params, _make_path, SKIP_IN_PATH
 
 
@@ -7,7 +11,7 @@ class IlmClient(NamespacedClient):
         """
         Deletes the specified lifecycle policy definition. A currently used policy
         cannot be deleted.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/ilm-delete-lifecycle.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/ilm-delete-lifecycle.html>`_
 
         :arg policy: The name of the index lifecycle policy
         """
@@ -26,7 +30,7 @@ class IlmClient(NamespacedClient):
         """
         Retrieves information about the index's current lifecycle state, such as the
         currently executing phase, action, and step.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/ilm-explain-lifecycle.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/ilm-explain-lifecycle.html>`_
 
         :arg index: The name of the index to explain
         :arg only_errors: filters the indices included in the response
@@ -46,7 +50,7 @@ class IlmClient(NamespacedClient):
         """
         Returns the specified policy definition. Includes the policy version and last
         modified date.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/ilm-get-lifecycle.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/ilm-get-lifecycle.html>`_
 
         :arg policy: The name of the index lifecycle policy
         """
@@ -58,7 +62,7 @@ class IlmClient(NamespacedClient):
     def get_status(self, params=None, headers=None):
         """
         Retrieves the current index lifecycle management (ILM) status.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/ilm-get-status.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/ilm-get-status.html>`_
         """
         return self.transport.perform_request(
             "GET", "/_ilm/status", params=params, headers=headers
@@ -68,7 +72,7 @@ class IlmClient(NamespacedClient):
     def move_to_step(self, index, body=None, params=None, headers=None):
         """
         Manually moves an index into the specified step and executes that step.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/ilm-move-to-step.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/ilm-move-to-step.html>`_
 
         :arg index: The name of the index whose lifecycle step is to
             change
@@ -89,7 +93,7 @@ class IlmClient(NamespacedClient):
     def put_lifecycle(self, policy, body=None, params=None, headers=None):
         """
         Creates a lifecycle policy
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/ilm-put-lifecycle.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/ilm-put-lifecycle.html>`_
 
         :arg policy: The name of the index lifecycle policy
         :arg body: The lifecycle policy definition to register
@@ -109,7 +113,7 @@ class IlmClient(NamespacedClient):
     def remove_policy(self, index, params=None, headers=None):
         """
         Removes the assigned lifecycle policy and stops managing the specified index
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/ilm-remove-policy.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/ilm-remove-policy.html>`_
 
         :arg index: The name of the index to remove policy on
         """
@@ -124,7 +128,7 @@ class IlmClient(NamespacedClient):
     def retry(self, index, params=None, headers=None):
         """
         Retries executing the policy for an index that is in the ERROR step.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/ilm-retry-policy.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/ilm-retry-policy.html>`_
 
         :arg index: The name of the indices (comma-separated) whose
             failed lifecycle step is to be retry
@@ -140,7 +144,7 @@ class IlmClient(NamespacedClient):
     def start(self, params=None, headers=None):
         """
         Start the index lifecycle management (ILM) plugin.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/ilm-start.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/ilm-start.html>`_
         """
         return self.transport.perform_request(
             "POST", "/_ilm/start", params=params, headers=headers
@@ -151,7 +155,7 @@ class IlmClient(NamespacedClient):
         """
         Halts all lifecycle management operations and stops the index lifecycle
         management (ILM) plugin
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/ilm-stop.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/ilm-stop.html>`_
         """
         return self.transport.perform_request(
             "POST", "/_ilm/stop", params=params, headers=headers
