@@ -1,3 +1,7 @@
+# Licensed to Elasticsearch B.V under one or more agreements.
+# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
+# See the LICENSE file in the project root for more information
+
 from .utils import NamespacedClient, query_params
 
 
@@ -6,7 +10,7 @@ class LicenseClient(NamespacedClient):
     def delete(self, params=None, headers=None):
         """
         Deletes licensing information for the cluster
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/delete-license.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/delete-license.html>`_
         """
         return self.transport.perform_request(
             "DELETE", "/_license", params=params, headers=headers
@@ -16,7 +20,7 @@ class LicenseClient(NamespacedClient):
     def get(self, params=None, headers=None):
         """
         Retrieves licensing information for the cluster
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/get-license.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/get-license.html>`_
 
         :arg accept_enterprise: If the active license is an enterprise
             license, return type as 'enterprise' (default: false)
@@ -31,7 +35,7 @@ class LicenseClient(NamespacedClient):
     def get_basic_status(self, params=None, headers=None):
         """
         Retrieves information about the status of the basic license.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/get-basic-status.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/get-basic-status.html>`_
         """
         return self.transport.perform_request(
             "GET", "/_license/basic_status", params=params, headers=headers
@@ -41,7 +45,7 @@ class LicenseClient(NamespacedClient):
     def get_trial_status(self, params=None, headers=None):
         """
         Retrieves information about the status of the trial license.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/get-trial-status.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/get-trial-status.html>`_
         """
         return self.transport.perform_request(
             "GET", "/_license/trial_status", params=params, headers=headers
@@ -51,7 +55,7 @@ class LicenseClient(NamespacedClient):
     def post(self, body=None, params=None, headers=None):
         """
         Updates the license for the cluster.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/update-license.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/update-license.html>`_
 
         :arg body: licenses to be installed
         :arg acknowledge: whether the user has acknowledged acknowledge
@@ -65,7 +69,7 @@ class LicenseClient(NamespacedClient):
     def post_start_basic(self, params=None, headers=None):
         """
         Starts an indefinite basic license.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/start-basic.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/start-basic.html>`_
 
         :arg acknowledge: whether the user has acknowledged acknowledge
             messages (default: false)
@@ -78,7 +82,7 @@ class LicenseClient(NamespacedClient):
     def post_start_trial(self, params=None, headers=None):
         """
         starts a limited time trial license.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/start-trial.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/start-trial.html>`_
 
         :arg acknowledge: whether the user has acknowledged acknowledge
             messages (default: false)
