@@ -1,3 +1,7 @@
+# Licensed to Elasticsearch B.V under one or more agreements.
+# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
+# See the LICENSE file in the project root for more information
+
 from .utils import NamespacedClient, query_params, _make_path
 
 
@@ -8,7 +12,7 @@ class MigrationClient(NamespacedClient):
         Retrieves information about different cluster, node, and index level settings
         that use deprecated features that will be removed or changed in the next major
         version.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/migration-api-deprecation.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/migration-api-deprecation.html>`_
 
         :arg index: Index pattern
         """
