@@ -1,3 +1,7 @@
+# Licensed to Elasticsearch B.V under one or more agreements.
+# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
+# See the LICENSE file in the project root for more information
+
 from .utils import NamespacedClient, query_params, _make_path, SKIP_IN_PATH
 
 
@@ -7,7 +11,7 @@ class SecurityClient(NamespacedClient):
         """
         Enables authentication as a user and retrieve information about the
         authenticated user.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-authenticate.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-authenticate.html>`_
         """
         return self.transport.perform_request(
             "GET", "/_security/_authenticate", params=params, headers=headers
@@ -17,7 +21,7 @@ class SecurityClient(NamespacedClient):
     def change_password(self, body, username=None, params=None, headers=None):
         """
         Changes the passwords of users in the native realm and built-in users.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-change-password.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-change-password.html>`_
 
         :arg body: the new password for the user
         :arg username: The username of the user to change the password
@@ -25,7 +29,7 @@ class SecurityClient(NamespacedClient):
         :arg refresh: If `true` (the default) then refresh the affected
             shards to make this operation visible to search, if `wait_for` then wait
             for a refresh to make this operation visible to search, if `false` then
-            do nothing with refreshes.   Valid choices: true, false, wait_for
+            do nothing with refreshes.  Valid choices: true, false, wait_for
         """
         if body in SKIP_IN_PATH:
             raise ValueError("Empty value passed for a required argument 'body'.")
@@ -43,7 +47,7 @@ class SecurityClient(NamespacedClient):
         """
         Evicts users from the user cache. Can completely clear the cache or evict
         specific users.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-clear-cache.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-clear-cache.html>`_
 
         :arg realms: Comma-separated list of realms to clear
         :arg usernames: Comma-separated list of usernames to clear from
@@ -63,7 +67,7 @@ class SecurityClient(NamespacedClient):
     def clear_cached_roles(self, name, params=None, headers=None):
         """
         Evicts roles from the native role cache.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-clear-role-cache.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-clear-role-cache.html>`_
 
         :arg name: Role name
         """
@@ -81,13 +85,13 @@ class SecurityClient(NamespacedClient):
     def create_api_key(self, body, params=None, headers=None):
         """
         Creates an API key for access without requiring basic authentication.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-create-api-key.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-create-api-key.html>`_
 
         :arg body: The api key request to create an API key
         :arg refresh: If `true` (the default) then refresh the affected
             shards to make this operation visible to search, if `wait_for` then wait
             for a refresh to make this operation visible to search, if `false` then
-            do nothing with refreshes.   Valid choices: true, false, wait_for
+            do nothing with refreshes.  Valid choices: true, false, wait_for
         """
         if body in SKIP_IN_PATH:
             raise ValueError("Empty value passed for a required argument 'body'.")
@@ -100,14 +104,14 @@ class SecurityClient(NamespacedClient):
     def delete_privileges(self, application, name, params=None, headers=None):
         """
         Removes application privileges.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-delete-privilege.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-delete-privilege.html>`_
 
         :arg application: Application name
         :arg name: Privilege name
         :arg refresh: If `true` (the default) then refresh the affected
             shards to make this operation visible to search, if `wait_for` then wait
             for a refresh to make this operation visible to search, if `false` then
-            do nothing with refreshes.   Valid choices: true, false, wait_for
+            do nothing with refreshes.  Valid choices: true, false, wait_for
         """
         for param in (application, name):
             if param in SKIP_IN_PATH:
@@ -124,13 +128,13 @@ class SecurityClient(NamespacedClient):
     def delete_role(self, name, params=None, headers=None):
         """
         Removes roles in the native realm.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-delete-role.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-delete-role.html>`_
 
         :arg name: Role name
         :arg refresh: If `true` (the default) then refresh the affected
             shards to make this operation visible to search, if `wait_for` then wait
             for a refresh to make this operation visible to search, if `false` then
-            do nothing with refreshes.   Valid choices: true, false, wait_for
+            do nothing with refreshes.  Valid choices: true, false, wait_for
         """
         if name in SKIP_IN_PATH:
             raise ValueError("Empty value passed for a required argument 'name'.")
@@ -146,13 +150,13 @@ class SecurityClient(NamespacedClient):
     def delete_role_mapping(self, name, params=None, headers=None):
         """
         Removes role mappings.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-delete-role-mapping.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-delete-role-mapping.html>`_
 
         :arg name: Role-mapping name
         :arg refresh: If `true` (the default) then refresh the affected
             shards to make this operation visible to search, if `wait_for` then wait
             for a refresh to make this operation visible to search, if `false` then
-            do nothing with refreshes.   Valid choices: true, false, wait_for
+            do nothing with refreshes.  Valid choices: true, false, wait_for
         """
         if name in SKIP_IN_PATH:
             raise ValueError("Empty value passed for a required argument 'name'.")
@@ -168,13 +172,13 @@ class SecurityClient(NamespacedClient):
     def delete_user(self, username, params=None, headers=None):
         """
         Deletes users from the native realm.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-delete-user.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-delete-user.html>`_
 
         :arg username: username
         :arg refresh: If `true` (the default) then refresh the affected
             shards to make this operation visible to search, if `wait_for` then wait
             for a refresh to make this operation visible to search, if `false` then
-            do nothing with refreshes.   Valid choices: true, false, wait_for
+            do nothing with refreshes.  Valid choices: true, false, wait_for
         """
         if username in SKIP_IN_PATH:
             raise ValueError("Empty value passed for a required argument 'username'.")
@@ -190,13 +194,13 @@ class SecurityClient(NamespacedClient):
     def disable_user(self, username, params=None, headers=None):
         """
         Disables users in the native realm.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-disable-user.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-disable-user.html>`_
 
         :arg username: The username of the user to disable
         :arg refresh: If `true` (the default) then refresh the affected
             shards to make this operation visible to search, if `wait_for` then wait
             for a refresh to make this operation visible to search, if `false` then
-            do nothing with refreshes.   Valid choices: true, false, wait_for
+            do nothing with refreshes.  Valid choices: true, false, wait_for
         """
         if username in SKIP_IN_PATH:
             raise ValueError("Empty value passed for a required argument 'username'.")
@@ -212,13 +216,13 @@ class SecurityClient(NamespacedClient):
     def enable_user(self, username, params=None, headers=None):
         """
         Enables users in the native realm.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-enable-user.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-enable-user.html>`_
 
         :arg username: The username of the user to enable
         :arg refresh: If `true` (the default) then refresh the affected
             shards to make this operation visible to search, if `wait_for` then wait
             for a refresh to make this operation visible to search, if `false` then
-            do nothing with refreshes.   Valid choices: true, false, wait_for
+            do nothing with refreshes.  Valid choices: true, false, wait_for
         """
         if username in SKIP_IN_PATH:
             raise ValueError("Empty value passed for a required argument 'username'.")
@@ -234,7 +238,7 @@ class SecurityClient(NamespacedClient):
     def get_api_key(self, params=None, headers=None):
         """
         Retrieves information for one or more API keys.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-get-api-key.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-get-api-key.html>`_
 
         :arg id: API key id of the API key to be retrieved
         :arg name: API key name of the API key to be retrieved
@@ -253,7 +257,7 @@ class SecurityClient(NamespacedClient):
     def get_privileges(self, application=None, name=None, params=None, headers=None):
         """
         Retrieves application privileges.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-get-privileges.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-get-privileges.html>`_
 
         :arg application: Application name
         :arg name: Privilege name
@@ -269,7 +273,7 @@ class SecurityClient(NamespacedClient):
     def get_role(self, name=None, params=None, headers=None):
         """
         Retrieves roles in the native realm.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-get-role.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-get-role.html>`_
 
         :arg name: Role name
         """
@@ -281,7 +285,7 @@ class SecurityClient(NamespacedClient):
     def get_role_mapping(self, name=None, params=None, headers=None):
         """
         Retrieves role mappings.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-get-role-mapping.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-get-role-mapping.html>`_
 
         :arg name: Role-Mapping name
         """
@@ -296,7 +300,7 @@ class SecurityClient(NamespacedClient):
     def get_token(self, body, params=None, headers=None):
         """
         Creates a bearer token for access without requiring basic authentication.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-get-token.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-get-token.html>`_
 
         :arg body: The token request to get
         """
@@ -311,7 +315,7 @@ class SecurityClient(NamespacedClient):
     def get_user(self, username=None, params=None, headers=None):
         """
         Retrieves information about users in the native realm and built-in users.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-get-user.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-get-user.html>`_
 
         :arg username: A comma-separated list of usernames
         """
@@ -326,7 +330,7 @@ class SecurityClient(NamespacedClient):
     def get_user_privileges(self, params=None, headers=None):
         """
         Retrieves application privileges.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-get-privileges.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-get-privileges.html>`_
         """
         return self.transport.perform_request(
             "GET", "/_security/user/_privileges", params=params, headers=headers
@@ -336,7 +340,7 @@ class SecurityClient(NamespacedClient):
     def has_privileges(self, body, user=None, params=None, headers=None):
         """
         Determines whether the specified user has a specified list of privileges.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-has-privileges.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-has-privileges.html>`_
 
         :arg body: The privileges to test
         :arg user: Username
@@ -356,7 +360,7 @@ class SecurityClient(NamespacedClient):
     def invalidate_api_key(self, body, params=None, headers=None):
         """
         Invalidates one or more API keys.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-invalidate-api-key.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-invalidate-api-key.html>`_
 
         :arg body: The api key request to invalidate API key(s)
         """
@@ -371,7 +375,7 @@ class SecurityClient(NamespacedClient):
     def invalidate_token(self, body, params=None, headers=None):
         """
         Invalidates one or more access tokens or refresh tokens.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-invalidate-token.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-invalidate-token.html>`_
 
         :arg body: The token to invalidate
         """
@@ -390,13 +394,13 @@ class SecurityClient(NamespacedClient):
     def put_privileges(self, body, params=None, headers=None):
         """
         Adds or updates application privileges.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-put-privileges.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-put-privileges.html>`_
 
         :arg body: The privilege(s) to add
         :arg refresh: If `true` (the default) then refresh the affected
             shards to make this operation visible to search, if `wait_for` then wait
             for a refresh to make this operation visible to search, if `false` then
-            do nothing with refreshes.   Valid choices: true, false, wait_for
+            do nothing with refreshes.  Valid choices: true, false, wait_for
         """
         if body in SKIP_IN_PATH:
             raise ValueError("Empty value passed for a required argument 'body'.")
@@ -409,14 +413,14 @@ class SecurityClient(NamespacedClient):
     def put_role(self, name, body, params=None, headers=None):
         """
         Adds and updates roles in the native realm.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-put-role.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-put-role.html>`_
 
         :arg name: Role name
         :arg body: The role to add
         :arg refresh: If `true` (the default) then refresh the affected
             shards to make this operation visible to search, if `wait_for` then wait
             for a refresh to make this operation visible to search, if `false` then
-            do nothing with refreshes.   Valid choices: true, false, wait_for
+            do nothing with refreshes.  Valid choices: true, false, wait_for
         """
         for param in (name, body):
             if param in SKIP_IN_PATH:
@@ -434,14 +438,14 @@ class SecurityClient(NamespacedClient):
     def put_role_mapping(self, name, body, params=None, headers=None):
         """
         Creates and updates role mappings.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-put-role-mapping.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-put-role-mapping.html>`_
 
         :arg name: Role-mapping name
         :arg body: The role mapping to add
         :arg refresh: If `true` (the default) then refresh the affected
             shards to make this operation visible to search, if `wait_for` then wait
             for a refresh to make this operation visible to search, if `false` then
-            do nothing with refreshes.   Valid choices: true, false, wait_for
+            do nothing with refreshes.  Valid choices: true, false, wait_for
         """
         for param in (name, body):
             if param in SKIP_IN_PATH:
@@ -460,14 +464,14 @@ class SecurityClient(NamespacedClient):
         """
         Adds and updates users in the native realm. These users are commonly referred
         to as native users.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-put-user.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-put-user.html>`_
 
         :arg username: The username of the User
         :arg body: The user to add
         :arg refresh: If `true` (the default) then refresh the affected
             shards to make this operation visible to search, if `wait_for` then wait
             for a refresh to make this operation visible to search, if `false` then
-            do nothing with refreshes.   Valid choices: true, false, wait_for
+            do nothing with refreshes.  Valid choices: true, false, wait_for
         """
         for param in (username, body):
             if param in SKIP_IN_PATH:
@@ -486,7 +490,7 @@ class SecurityClient(NamespacedClient):
         """
         Retrieves the list of cluster privileges and index privileges that are
         available in this version of Elasticsearch.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-get-builtin-privileges.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-get-builtin-privileges.html>`_
         """
         return self.transport.perform_request(
             "GET", "/_security/privilege/_builtin", params=params, headers=headers
