@@ -1,3 +1,7 @@
+# Licensed to Elasticsearch B.V under one or more agreements.
+# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
+# See the LICENSE file in the project root for more information
+
 from .utils import NamespacedClient, query_params, _make_path, SKIP_IN_PATH
 
 
@@ -6,7 +10,7 @@ class SnapshotClient(NamespacedClient):
     def create(self, repository, snapshot, body=None, params=None, headers=None):
         """
         Creates a snapshot in a repository.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/modules-snapshots.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/modules-snapshots.html>`_
 
         :arg repository: A repository name
         :arg snapshot: A snapshot name
@@ -32,7 +36,7 @@ class SnapshotClient(NamespacedClient):
     def delete(self, repository, snapshot, params=None, headers=None):
         """
         Deletes a snapshot.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/modules-snapshots.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/modules-snapshots.html>`_
 
         :arg repository: A repository name
         :arg snapshot: A snapshot name
@@ -54,7 +58,7 @@ class SnapshotClient(NamespacedClient):
     def get(self, repository, snapshot, params=None, headers=None):
         """
         Returns information about a snapshot.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/modules-snapshots.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/modules-snapshots.html>`_
 
         :arg repository: A repository name
         :arg snapshot: A comma-separated list of snapshot names
@@ -81,7 +85,7 @@ class SnapshotClient(NamespacedClient):
     def delete_repository(self, repository, params=None, headers=None):
         """
         Deletes a repository.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/modules-snapshots.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/modules-snapshots.html>`_
 
         :arg repository: Name of the snapshot repository to unregister.
             Wildcard (`*`) patterns are supported.
@@ -103,7 +107,7 @@ class SnapshotClient(NamespacedClient):
     def get_repository(self, repository=None, params=None, headers=None):
         """
         Returns information about a repository.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/modules-snapshots.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/modules-snapshots.html>`_
 
         :arg repository: A comma-separated list of repository names
         :arg local: Return local information, do not retrieve the state
@@ -119,7 +123,7 @@ class SnapshotClient(NamespacedClient):
     def create_repository(self, repository, body, params=None, headers=None):
         """
         Creates a repository.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/modules-snapshots.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/modules-snapshots.html>`_
 
         :arg repository: A repository name
         :arg body: The repository definition
@@ -144,7 +148,7 @@ class SnapshotClient(NamespacedClient):
     def restore(self, repository, snapshot, body=None, params=None, headers=None):
         """
         Restores a snapshot.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/modules-snapshots.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/modules-snapshots.html>`_
 
         :arg repository: A repository name
         :arg snapshot: A snapshot name
@@ -170,7 +174,7 @@ class SnapshotClient(NamespacedClient):
     def status(self, repository=None, snapshot=None, params=None, headers=None):
         """
         Returns information about the status of a snapshot.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/modules-snapshots.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/modules-snapshots.html>`_
 
         :arg repository: A repository name
         :arg snapshot: A comma-separated list of snapshot names
@@ -191,7 +195,7 @@ class SnapshotClient(NamespacedClient):
     def verify_repository(self, repository, params=None, headers=None):
         """
         Verifies a repository.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/modules-snapshots.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/modules-snapshots.html>`_
 
         :arg repository: A repository name
         :arg master_timeout: Explicit operation timeout for connection
@@ -212,7 +216,7 @@ class SnapshotClient(NamespacedClient):
     def cleanup_repository(self, repository, params=None, headers=None):
         """
         Removes stale data from repository.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/clean-up-snapshot-repo-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/clean-up-snapshot-repo-api.html>`_
 
         :arg repository: A repository name
         :arg master_timeout: Explicit operation timeout for connection
