@@ -1,3 +1,7 @@
+# Licensed to Elasticsearch B.V under one or more agreements.
+# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
+# See the LICENSE file in the project root for more information
+
 import warnings
 from .utils import NamespacedClient, query_params, _make_path, SKIP_IN_PATH
 
@@ -15,13 +19,13 @@ class TasksClient(NamespacedClient):
     def list(self, params=None, headers=None):
         """
         Returns a list of tasks.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/tasks.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/tasks.html>`_
 
         :arg actions: A comma-separated list of actions that should be
             returned. Leave empty to return all.
         :arg detailed: Return detailed task information (default: false)
         :arg group_by: Group tasks by nodes or parent/child
-            relationships   Valid choices: nodes, parents, none   Default: nodes
+            relationships  Valid choices: nodes, parents, none  Default: nodes
         :arg nodes: A comma-separated list of node IDs or names to limit
             the returned information; use `_local` to return information from the
             node you're connecting to, leave empty to get information from all nodes
@@ -35,11 +39,11 @@ class TasksClient(NamespacedClient):
             "GET", "/_tasks", params=params, headers=headers
         )
 
-    @query_params("actions", "nodes", "parent_task_id")
+    @query_params("actions", "nodes", "parent_task_id", "wait_for_completion")
     def cancel(self, task_id=None, params=None, headers=None):
         """
         Cancels a task, if it can be cancelled through an API.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/tasks.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/tasks.html>`_
 
         :arg task_id: Cancel the task with specified task id
             (node_id:task_number)
@@ -50,6 +54,9 @@ class TasksClient(NamespacedClient):
             node you're connecting to, leave empty to get information from all nodes
         :arg parent_task_id: Cancel tasks with specified parent task id
             (node_id:task_number). Set to -1 to cancel all.
+        :arg wait_for_completion: Should the request block until the
+            cancellation of the task and its descendant tasks is completed. Defaults
+            to false
         """
         return self.transport.perform_request(
             "POST",
@@ -62,7 +69,7 @@ class TasksClient(NamespacedClient):
     def get(self, task_id=None, params=None, headers=None):
         """
         Returns information about a task.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/tasks.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/tasks.html>`_
 
         :arg task_id: Return the task with specified id
             (node_id:task_number)
@@ -75,7 +82,6 @@ class TasksClient(NamespacedClient):
                 "Calling client.tasks.get() without a task_id is deprecated "
                 "and will be removed in v8.0. Use client.tasks.list() instead.",
                 category=DeprecationWarning,
-                stacklevel=3,
             )
 
         return self.transport.perform_request(
