@@ -1,3 +1,7 @@
+# Licensed to Elasticsearch B.V under one or more agreements.
+# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
+# See the LICENSE file in the project root for more information
+
 from .utils import NamespacedClient, query_params, _make_path, SKIP_IN_PATH
 
 
@@ -6,7 +10,7 @@ class WatcherClient(NamespacedClient):
     def ack_watch(self, watch_id, action_id=None, params=None, headers=None):
         """
         Acknowledges a watch, manually throttling the execution of the watch's actions.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/watcher-api-ack-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/watcher-api-ack-watch.html>`_
 
         :arg watch_id: Watch ID
         :arg action_id: A comma-separated list of the action ids to be
@@ -26,7 +30,7 @@ class WatcherClient(NamespacedClient):
     def activate_watch(self, watch_id, params=None, headers=None):
         """
         Activates a currently inactive watch.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/watcher-api-activate-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/watcher-api-activate-watch.html>`_
 
         :arg watch_id: Watch ID
         """
@@ -44,7 +48,7 @@ class WatcherClient(NamespacedClient):
     def deactivate_watch(self, watch_id, params=None, headers=None):
         """
         Deactivates a currently active watch.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/watcher-api-deactivate-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/watcher-api-deactivate-watch.html>`_
 
         :arg watch_id: Watch ID
         """
@@ -62,7 +66,7 @@ class WatcherClient(NamespacedClient):
     def delete_watch(self, id, params=None, headers=None):
         """
         Removes a watch from Watcher.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/watcher-api-delete-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/watcher-api-delete-watch.html>`_
 
         :arg id: Watch ID
         """
@@ -80,7 +84,7 @@ class WatcherClient(NamespacedClient):
     def execute_watch(self, body=None, id=None, params=None, headers=None):
         """
         Forces the execution of a stored watch.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/watcher-api-execute-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/watcher-api-execute-watch.html>`_
 
         :arg body: Execution control
         :arg id: Watch ID
@@ -99,7 +103,7 @@ class WatcherClient(NamespacedClient):
     def get_watch(self, id, params=None, headers=None):
         """
         Retrieves a watch by its ID.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/watcher-api-get-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/watcher-api-get-watch.html>`_
 
         :arg id: Watch ID
         """
@@ -114,7 +118,7 @@ class WatcherClient(NamespacedClient):
     def put_watch(self, id, body=None, params=None, headers=None):
         """
         Creates a new watch, or updates an existing one.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/watcher-api-put-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/watcher-api-put-watch.html>`_
 
         :arg id: Watch ID
         :arg body: The watch
@@ -140,7 +144,7 @@ class WatcherClient(NamespacedClient):
     def start(self, params=None, headers=None):
         """
         Starts Watcher if it is not already running.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/watcher-api-start.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/watcher-api-start.html>`_
         """
         return self.transport.perform_request(
             "POST", "/_watcher/_start", params=params, headers=headers
@@ -150,10 +154,10 @@ class WatcherClient(NamespacedClient):
     def stats(self, metric=None, params=None, headers=None):
         """
         Retrieves the current Watcher metrics.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/watcher-api-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/watcher-api-stats.html>`_
 
         :arg metric: Controls what additional stat metrics should be
-            include in the response   Valid choices: _all, queued_watches,
+            include in the response  Valid choices: _all, queued_watches,
             current_watches, pending_watches
         :arg emit_stacktraces: Emits stack traces of currently running
             watches
@@ -169,7 +173,7 @@ class WatcherClient(NamespacedClient):
     def stop(self, params=None, headers=None):
         """
         Stops Watcher if it is running.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/watcher-api-stop.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/watcher-api-stop.html>`_
         """
         return self.transport.perform_request(
             "POST", "/_watcher/_stop", params=params, headers=headers
